@@ -3,7 +3,7 @@
  *  Definition of optimizing macros. */
 
 /*
- *  GiNaC Copyright (C) 1999-2022 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2025 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -27,10 +27,12 @@
 #define unlikely(cond) __builtin_expect((cond), 0)
 #define likely(cond) __builtin_expect((cond), 1)
 #define attribute_deprecated __attribute__ ((deprecated))
+#define attribute_pure __attribute__((__pure__))
 #else
 #define unlikely(cond) (cond)
 #define likely(cond) (cond)
 #define attribute_deprecated
+#define attribute_pure
 #endif
 
 #endif // ndef GINAC_COMPILER_DEP_H
