@@ -3,10 +3,10 @@
 # Convert help for ginsh operators from man page to C source
 import sys, re, optparse
 
-rxStart = re.compile('^.*GINSH_OP_HELP_START$')
-rxEnd = re.compile('^.*GINSH_OP_HELP_END$')
-fcnRx = re.compile('^[.]B\s+')
-minusRx = re.compile('\\\\[-]')
+rxStart = re.compile(r'^.*GINSH_OP_HELP_START$')
+rxEnd = re.compile(r'^.*GINSH_OP_HELP_END$')
+fcnRx = re.compile(r'^[.]B\s+')
+minusRx = re.compile(r'\\[-]')
 codeFmt = 'insert_help("operators", "%s\\t" "%s");\n'
 
 def extractHelp(inp, out):
@@ -23,8 +23,8 @@ def extractHelp(inp, out):
 				out.write(codeFmt % ( sym, synopsis ))
 			break
 		if fcnRx.match(l):
-			l = fcnRx.sub('', l)
-			sym = minusRx.sub('-', l)
+			l = fcnRx.sub(r'', l)
+			sym = minusRx.sub(r'-', l)
 		elif l.lower() == '.tp':
 			out.write(codeFmt % ( sym, synopsis ))
 			sym, synopsis = None, None
